==> unity-chromium-extension_2.4.8+13.10.20130920.1.orig.tar.gz: unity-chromium-extension-2.4.8+13.10.20130920.1/npapi-plugin/src/unity-webapps-repository-binding.h <==
/*
 * unity-webapps-repository-binding.h
 * Copyright (C) Canonical LTD 2012
 * 
 * Author: Alexandre Abreu <alexandre.abreu@canonical.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#if ! defined (UNITY_WEBAPPS_REPOSITORY_BINDING_H)
#define UNITY_WEBAPPS_REPOSITORY_BINDING_H

#include "npapi-headers/headers/npapi.h"
#include "npapi-headers/headers/npruntime.h"
#include "npapi-headers/headers/nptypes.h"


NPVariant
unity_webapps_binding_application_repository_new_default (NPP instance
                                                          , NPObject * object
                                                          , const NPVariant *args
                                                          , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_prepare (NPP instance
                                                      , NPObject * object
                                                      , const NPVariant *args
                                                      , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_resolve_url_as_json (NPP instance
                                                          , NPObject * object
                                                          , const NPVariant *args
                                                          , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_get_resolved_application_status (NPP instance
                                                                              , NPObject * object
                                                                              , const NPVariant *args
                                                                              , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_install_application (NPP instance
                                                                  , NPObject * object
                                                                  , const NPVariant *args
                                                                  , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_get_userscript_contents (NPP instance
                                                                      , NPObject * object
                                                                      , const NPVariant *args
                                                                      , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_get_resolved_application_domain (NPP instance
                                                                              , NPObject * object
                                                                              , const NPVariant *args
                                                                              , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_get_resolved_application_name (NPP instance
                                                                            , NPObject * object
                                                                            , const NPVariant *args
                                                                            , uint32_t argCount);

#endif // UNITY_WEBAPPS_REPOSITORY_BINDING_H

==> unity-chromium-extension_3.0.0+14.04.20140318.orig.tar.gz: unity-chromium-extension-3.0.0+14.04.20140318/npapi-plugin/src/unity-webapps-repository-binding.h <==
/*
 * unity-webapps-repository-binding.h
 * Copyright (C) Canonical LTD 2012
 * 
 * Author: Alexandre Abreu <alexandre.abreu@canonical.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#if ! defined (UNITY_WEBAPPS_REPOSITORY_BINDING_H)
#define UNITY_WEBAPPS_REPOSITORY_BINDING_H

#include "npapi-headers/headers/npapi.h"
#include "npapi-headers/headers/npruntime.h"
#include "npapi-headers/headers/nptypes.h"


NPVariant
unity_webapps_binding_application_repository_add_desktop_to_launcher (NPP instance
								      , NPObject * object
								      , const NPVariant *args
								      , uint32_t argCount);
NPVariant
unity_webapps_binding_application_repository_generate_desktop_for_url_launch (NPP instance
									      , NPObject * object
									      , const NPVariant *args
									      , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_new_default (NPP instance
                                                          , NPObject * object
                                                          , const NPVariant *args
                                                          , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_prepare (NPP instance
                                                      , NPObject * object
                                                      , const NPVariant *args
                                                      , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_resolve_url_as_json (NPP instance
                                                          , NPObject * object
                                                          , const NPVariant *args
                                                          , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_get_resolved_application_status (NPP instance
                                                                              , NPObject * object
                                                                              , const NPVariant *args
                                                                              , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_install_application (NPP instance
                                                                  , NPObject * object
                                                                  , const NPVariant *args
                                                                  , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_get_userscript_contents (NPP instance
                                                                      , NPObject * object
                                                                      , const NPVariant *args
                                                                      , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_get_resolved_application_domain (NPP instance
                                                                              , NPObject * object
                                                                              , const NPVariant *args
                                                                              , uint32_t argCount);

NPVariant
unity_webapps_binding_application_repository_get_resolved_application_name (NPP instance
                                                                            , NPObject * object
                                                                            , const NPVariant *args
                                                                            , uint32_t argCount);

#endif // UNITY_WEBAPPS_REPOSITORY_BINDING_H
